# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br)

[![Build Status](https://travis-ci.com/wosubtil/libpythonpro.svg?branch=master)](https://travis-ci.com/wosubtil/libpythonpro)
[![Updates](https://pyup.io/repos/github/wosubtil/libpythonpro/shield.svg)](https://pyup.io/repos/github/wosubtil/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/wosubtil/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/wosubtil/libpythonpro/)

Suportada versão 3 do Python

Para instalar:

```console
python -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir a qualidade do código:
```console
flake8
```


Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip

